<?php

namespace Drupal\informea_api;

use Drupal\views\Render\ViewsRenderPipelineMarkup;
use Drupal\rest_views\SerializedData as DrupalSerializedData;

/**
 * Wrapper for passing serialized data through render arrays.
 *
 * @see \Drupal\informea_api\Normalizer\DataNormalizer
 */
class SerializedData extends DrupalSerializedData {

  /**
   * SerializedData constructor.
   *
   * @param mixed $data
   *   The wrapped data.
   */
  public function __construct($data) {
    if (!empty($data) && is_array($data) && !empty($data[0]) && $data[0] instanceof static) {
      $this->data = $data[0]->data;
      return;
    }
    $this->data = $data;
  }

  /**
   * Convert renderable object to a string.
   *
   * This function needs to return a non-empty string in order to be processed
   * correctly by Drupal's rendering system.
   *
   * @return string
   *   A placeholder string representation.
   */
  public function __toString() {
    // This must not be empty.
    if ($this->data && $this->data instanceof ViewsRenderPipelineMarkup) {
      return $this->data->__toString();
    }
    return '[...]';
  }

}
